# -*- coding: utf-8 -*-
import sys
from urllib.parse import urlparse

from intelmq.lib.bot import ParserBot
from intelmq.lib.exceptions import InvalidValue
from intelmq.lib.message import Event


class MalwareDomainListParserBot(ParserBot):
    def add_http(self, url):
        """
        We can assume here, that everything is http by default if not given.
        """
        if '://' not in url:
            return 'http://' + url

    parse = ParserBot.parse_csv
    recover_line = ParserBot.recover_line_csv

    def parse_line(self, row, report):
        event = Event(report)

        event.add("time.source", row[0].replace('_', ' ') + " UTC")
        if row[1] != '-':
            event.add("source.url", self.add_http(row[1]))
        try:
            event.add("source.ip", row[2])
        except InvalidValue:
            event.add("source.url", self.add_http(row[2]))
            event.add('source.ip', urlparse(row[2]).netloc)
        event.add("source.reverse_dns", row[3])
        event.add("event_description.text", row[4])
        # TODO: ignore abuse contact for now
        event.add("source.asn", int(row[6]))

        event.add('classification.type', 'malware')
        event.add("raw", self.recover_line(row))
        yield event

if __name__ == "__main__":
    bot = MalwareDomainListParserBot(sys.argv[1])
    bot.start()
